@@ -3,6 +3,7 @@
 #'@description Either captures the current rgl view and displays, or saves the current view to disk. 
 #'
 #'@param filename Filename of snapshot. If missing, will display to current device.
+#'@param clear Default `FALSE`. If `TRUE`, the current `rgl` device will be cleared.
 #'@return Displays snapshot of current rgl plot (or saves to disk).
 #'@export
 #'@examples
@@ -13,16 +14,18 @@
 #'}
 #'  
 #'\dontrun{
-#'render_snapshot()
-#'rgl::rgl.clear()
+#'render_snapshot(clear = TRUE)
 #'}
-render_snapshot = function(filename) {
+render_snapshot = function(filename, clear=FALSE) {
   temp = paste0(tempfile(),".png")
-  rgl::snapshot3d(filename=temp)
+  rgl::snapshot3d(filename = temp)
   tempmap = png::readPNG(temp)
   if(missing(filename)) {
     plot_map(tempmap)
   } else {
-    save_png(tempmap,filename)
+    save_png(tempmap, filename)
+  }
+  if(clear) {
+    rgl::rgl.clear()
   }
 }
